==> beast-0.4.1-rc3.tar.gz: beast-0.4.1-rc3/bse/bsebuiltin_externs.c <==

/**
 ** Generated data (by mkbuiltinlist.pl --externs)
 **/

/* --- bsescripthelper.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bsescripthelper_gen_proc);

/* --- bseenums.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bseenums_gen_proc);

/* --- bsesource.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bsesource_gen_proc);

/* --- bsewaverepo.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bsewaverepo_gen_proc);

/* --- bsehelloworld.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bsehelloworld_gen_proc);

/* --- bsecontainer.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bsecontainer_gen_proc);

/* --- bseeditablesample.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bseeditablesample_gen_proc);

/* --- bsepart.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bsepart_gen_proc);

/* --- bsewave.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bsewave_gen_proc);

/* --- bsesong.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bsesong_gen_proc);

/* --- bseserver.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bseserver_gen_proc);

/* --- bsemidinotifier.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bsemidinotifier_gen_proc);

/* --- bseitem.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bseitem_gen_proc);

/* --- bsedatapocket.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bsedatapocket_gen_proc);

/* --- bseobject.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bseobject_gen_proc);

/* --- bsewaveosc.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bsewaveosc_gen_proc);

/* --- bsesnet.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bsesnet_gen_proc);

/* --- bsescriptcontrol.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bsescriptcontrol_gen_proc);

/* --- bseproject.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bseproject_gen_proc);

/* --- bseprocedure.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bseprocedure_gen_proc);

/**
 ** Generated data ends here
 **/

==> beast-0.5.0.tar.gz: beast-0.5.0/bse/bsebuiltin_externs.c <==

/**
 ** Generated data (by mkbuiltinlist.pl --externs)
 **/

/* --- bsehelloworld.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bsehelloworld_gen_proc);

/* --- bsetrack.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bsetrack_gen_proc);

/* --- bseeditablesample.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bseeditablesample_gen_proc);

/* --- bsewave.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bsewave_gen_proc);

/* --- bseserver.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bseserver_gen_proc);

/* --- bseitem.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bseitem_gen_proc);

/* --- bsedatapocket.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bsedatapocket_gen_proc);

/* --- bseobject.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bseobject_gen_proc);

/* --- bsesnet.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bsesnet_gen_proc);

/* --- bseproject.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bseproject_gen_proc);

/* --- bseenums.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bseenums_gen_proc);

/* --- bsescripthelper.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bsescripthelper_gen_proc);

/* --- bsecategories.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bsecategories_gen_proc);

/* --- bsesource.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bsesource_gen_proc);

/* --- bsewaverepo.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bsewaverepo_gen_proc);

/* --- bsejanitor.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bsejanitor_gen_proc);

/* --- bsepart.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bsepart_gen_proc);

/* --- bsecontainer.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bsecontainer_gen_proc);

/* --- bsemidinotifier.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bsemidinotifier_gen_proc);

/* --- bsesong.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bsesong_gen_proc);

/* --- bsewaveosc.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bsewaveosc_gen_proc);

/* --- bseprocedure.gen-proc.c --- */
extern BSE_EXPORT_IMPL_F (bseprocedure_gen_proc);

/**
 ** Generated data ends here
 **/
